mod assets_copier;
mod data_extractor;
mod file_content_loader;
mod folder_copier;
mod html_compiler;
mod index_compiler;
mod pages_compiler;
mod settings_serializer;
mod template_filler;
mod template_finder;
mod template_initializer;
mod video_serializer;

fn main() {
    assets_copier::call();
    index_compiler::call();
    pages_compiler::call();
}
